pub unsafe auto trait Leak { }Expand description
The core trait of the destruction guarantee.
Safety
Implement only if you know there’s absolutely no possible way to forget your type.
pub unsafe auto trait Leak { }The core trait of the destruction guarantee.
Implement only if you know there’s absolutely no possible way to forget your type.